from distutils.core import setup

setup(
    name='tulgey',
    version='0.1.12',
    author='David Dworken',
    author_email='david@daviddworken.com',
    packages=['tulgey', 'tulgey.db', 'tulgey.utils'],
    url='http://pypi.python.org/pypi/tulgey/',
    license='LICENSE.txt',
    description='tulgey python utils',
)
